@@ -14,14 +14,17 @@
  * more details.
  *
  * You should have received a copy of the GNU General Public License along with
- * this program; if not, write to the Free Software Foundation, Inc., 51
- * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef __ONAK_CONF_H_
 #define __ONAK_CONF_H_
 
-#include "keydb.h"
+#include <stdbool.h>
+#include <stdint.h>
+
+#include "keyarray.h"
+#include "ll.h"
 
 /**
  * @brief Backend database configuration.
@@ -87,8 +90,11 @@ struct onak_config {
 	/** Pointer to the initialisation function for our loaded DB backend */
 	struct onak_dbctx *(*dbinit)(struct onak_db_config *, bool);
 
-	/** Should we verify signature hashes match? */
-	bool check_sighash;
+	/** Blacklist of fingerprints to reject */
+	struct keyarray blacklist;
+
+	/** What policies should we use for cleaning keys? */
+	uint64_t clean_policies;
 
 	/*
 	 * Options used by the email handling script.
