@@ -13,10 +13,10 @@
  * more details.
  *
  * You should have received a copy of the GNU General Public License along with
- * this program; if not, write to the Free Software Foundation, Inc., 51
- * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+#include <inttypes.h>
 #include <stdio.h>
 #include <stdlib.h>
 
@@ -25,7 +25,6 @@
 #include "hash.h"
 #include "keydb.h"
 #include "ll.h"
-#include "onak-conf.h"
 #include "stats.h"
 
 /**
@@ -137,25 +136,21 @@ void dofindpath(struct onak_dbctx *dbctx,
 		uint64_t have, uint64_t want, bool html, int count)
 {
 	struct stats_key *keyinfoa, *keyinfob, *curkey;
-	uint64_t fullhave, fullwant;
 	int rec;
 	int pathnum;
 	char *uid;
 
-	fullhave = dbctx->getfullkeyid(dbctx, have);
-	fullwant = dbctx->getfullkeyid(dbctx, want);
-
 	/*
 	 * Make sure the keys we have and want are in the cache.
 	 */
-	(void) dbctx->cached_getkeysigs(dbctx, fullhave);
-	(void) dbctx->cached_getkeysigs(dbctx, fullwant);
+	(void) dbctx->cached_getkeysigs(dbctx, have);
+	(void) dbctx->cached_getkeysigs(dbctx, want);
 
-	if ((keyinfoa = findinhash(fullhave)) == NULL) {
+	if ((keyinfoa = findinhash(have)) == NULL) {
 		printf("Couldn't find key 0x%016" PRIX64 ".\n", have);
 		return;
 	}
-	if ((keyinfob = findinhash(fullwant)) == NULL) {
+	if ((keyinfob = findinhash(want)) == NULL) {
 		printf("Couldn't find key 0x%016" PRIX64 ".\n", want);
 		return;
 	}
@@ -177,8 +172,8 @@ void dofindpath(struct onak_dbctx *dbctx,
 			html ? "<BR>" : "");
 		if (keyinfoa->colour == 0) {
 			if (pathnum == 0) {
-				printf("Can't find a link from 0x%08" PRIX64
-				" to 0x%08" PRIX64 "%s\n",
+				printf("Can't find a link from 0x%016" PRIX64
+				" to 0x%016" PRIX64 "%s\n",
 				have,
 				want,
 				html ? "<BR>" : "");
@@ -188,10 +183,10 @@ void dofindpath(struct onak_dbctx *dbctx,
 			}
 			pathnum = count;
 		} else {
-			printf("%d steps from 0x%08" PRIX64 " to 0x%08" PRIX64
-				"%s\n",
-				keyinfoa->colour, have & 0xFFFFFFFF,
-				want & 0xFFFFFFFF,
+			printf("%d steps from 0x%016" PRIX64 " to 0x%016"
+				PRIX64 "%s\n",
+				keyinfoa->colour, have,
+				want,
 				html ? "<BR>" : "");
 			curkey = keyinfoa;
 			while (curkey != NULL && curkey->keyid != 0) {
@@ -199,34 +194,34 @@ void dofindpath(struct onak_dbctx *dbctx,
 						curkey->keyid);
 				if (html && uid == NULL) {
 					printf("<a href=\"lookup?op=get&search="
-						"0x%08" PRIX64 "\">0x%08" PRIX64
-						"</a> (["
+						"0x%016" PRIX64 "\">0x%016"
+						PRIX64 "</a> (["
 						"User id not found])%s<BR>\n",
-						curkey->keyid & 0xFFFFFFFF,
-						curkey->keyid & 0xFFFFFFFF,
-						(curkey->keyid == fullwant) ?
+						curkey->keyid,
+						curkey->keyid,
+						(curkey->keyid == want) ?
 							"" : " signs");
 				} else if (html && uid != NULL) {
 					printf("<a href=\"lookup?op=get&search="
-						"0x%08" PRIX64 "\">0x%08"
+						"0x%016" PRIX64 "\">0x%016"
 						PRIX64 "</a>"
 						" (<a href=\"lookup?op=vindex&"
-						"search=0x%08" PRIX64 
+						"search=0x%016" PRIX64
 						"\">%s</a>)%s"
 						"<BR>\n",
-						curkey->keyid & 0xFFFFFFFF,
-						curkey->keyid & 0xFFFFFFFF,
-						curkey->keyid & 0xFFFFFFFF,
+						curkey->keyid,
+						curkey->keyid,
+						curkey->keyid,
 						txt2html(uid),
-						(curkey->keyid == fullwant) ?
+						(curkey->keyid == want) ?
 						"" : " signs");
 				} else {
-					printf("0x%08" PRIX64 " (%s)%s\n",
-						curkey->keyid & 0xFFFFFFFF,
+					printf("0x%016" PRIX64 " (%s)%s\n",
+						curkey->keyid,
 						(uid == NULL) ?
 							"[User id not found]" :
 							uid,
-						(curkey->keyid == fullwant) ?
+						(curkey->keyid == want) ?
 						"" : " signs");
 				}
 				if (uid != NULL) {
@@ -245,8 +240,8 @@ void dofindpath(struct onak_dbctx *dbctx,
 			}
 			curkey = keyinfoa;
 			while (curkey != NULL && curkey->keyid != 0) {
-				printf("0x%08" PRIX64 " ",
-						curkey->keyid & 0xFFFFFFFF);
+				printf("0x%016" PRIX64 " ",
+						curkey->keyid);
 				curkey = findinhash(curkey->parent);
 			}
 			putchar('\n');
